.. _configaro_releases:

=======
Changes
=======

..  toctree::
    :maxdepth: 2
    :caption: Contents:

.. _configaro_release_0_9_5:

0.9.5
=====

Features
--------

- :meth:`configaro.get` now accepts *not_found* keyword arg to pass value to be returned if property is not found, instead of raising error
- expanded test coverage
- improvements to documentation

.. _configaro_release_0_9_4:

0.9.4
=====

Features
--------

- improvements to automation
- improvements to documentation
- improvements to :meth:`configaro.put`

Changes
-------

- converted to single module library
- removed duplication of release metadata
- renamed :meth:`configaro.initialize` to :meth:`configaro.init`

.. _configaro_release_0_9_3:

0.9.3
=====

Fixes
-----

- documentation build fixes

.. _configaro_release_0_9_2:

0.9.2
=====

Fixes
-----

- packaging and requirements fixes

Deletions
---------

- :meth:`configaro.render`

.. _configaro_release_0_9_1:

0.9.1
=====

Features
--------

- documentation improvements

.. _configaro_release_0_9_0:

0.9.0
=====

Initial release of package.

Features
--------

- a simple API that is easy to use and gets out of your way
- a system that allows for hierarchical configuration data that supports dot-addressable property access
- a system that allows for configuration defaults and local overrides
- a system with high degree of test coverage
- a system with high degree of documentation

Fixes
-----

- none

Changes
-------

- none

Deprecations
------------

- none

Deletions
---------

- none
